@@ -3,7 +3,8 @@ import React, { PropTypes } from 'react';
 export default function PropertyHidden(_ref) {
   var value = _ref.value,
       onUpdate = _ref.onUpdate,
-      configs = _ref.configs;
+      configs = _ref.configs,
+      sourceElement = _ref.sourceElement;
 
   return null;
 }
@@ -11,5 +12,6 @@ export default function PropertyHidden(_ref) {
 PropertyHidden.propTypes = {
   value: PropTypes.any.isRequired,
   onUpdate: PropTypes.func.isRequired,
-  configs: PropTypes.object.isRequired
+  configs: PropTypes.object.isRequired,
+  sourceElement: PropTypes.object
 };
\ No newline at end of file
