@@ -151,20 +151,22 @@ var ElementEditor = function (_Component) {
         case 'lines':
           {
             if (attributeName === 'lineLength') {
-              var v_0 = attributesFormData.get('vertexOne');
-              var v_1 = attributesFormData.get('vertexTwo');
+              (function () {
+                var v_0 = attributesFormData.get('vertexOne');
+                var v_1 = attributesFormData.get('vertexTwo');
 
-              var _geometry$orderVertic = geometry.orderVertices([v_0, v_1]),
-                  _geometry$orderVertic2 = _slicedToArray(_geometry$orderVertic, 2),
-                  v_a = _geometry$orderVertic2[0],
-                  v_b = _geometry$orderVertic2[1];
+                var _geometry$orderVertic = geometry.orderVertices([v_0, v_1]),
+                    _geometry$orderVertic2 = _slicedToArray(_geometry$orderVertic, 2),
+                    v_a = _geometry$orderVertic2[0],
+                    v_b = _geometry$orderVertic2[1];
 
-              var v_b_new = geometry.extendLine(v_a.x, v_a.y, v_b.x, v_b.y, value.get('length'), 2);
+                var v_b_new = geometry.extendLine(v_a.x, v_a.y, v_b.x, v_b.y, value.get('length'), 2);
 
-              attributesFormData = attributesFormData.withMutations(function (attr) {
-                attr.set(v_0 === v_a ? 'vertexTwo' : 'vertexOne', v_b.merge(v_b_new));
-                attr.set('lineLength', value);
-              });
+                attributesFormData = attributesFormData.withMutations(function (attr) {
+                  attr.set(v_0 === v_a ? 'vertexTwo' : 'vertexOne', v_b.merge(v_b_new));
+                  attr.set('lineLength', value);
+                });
+              })();
             } else {
               attributesFormData = attributesFormData.withMutations(function (attr) {
                 attr.set(attributeName, attr.get(attributeName).merge(value));
@@ -338,7 +340,8 @@ var ElementEditor = function (_Component) {
             onUpdate: function onUpdate(value) {
               return _this3.updateProperty(propertyName, value);
             },
-            state: appState
+            state: appState,
+            sourceElement: _this3.props.element
           });
         }),
         React.createElement(
@@ -355,8 +358,7 @@ var ElementEditor = function (_Component) {
                 null,
                 React.createElement(
                   DeleteButton,
-                  { size: 'small',
-                    onClick: function onClick(e) {
+                  { size: 'small', onClick: function onClick(e) {
                       return projectActions.remove();
                     } },
                   translator.t("Delete")
