@@ -2,13 +2,12 @@ import React, {PropTypes} from 'react';
 import FormLabel from '../../components/style/form-label'
 import FormColorInput from '../../components/style/form-color-input';
 
-let firstTdStyle = {
-  width: '6em'
-};
+const tableStyle = { width: "100%", borderSpacing: "2px 0", marginBottom: "2px" };
+const firstTdStyle = { width: '6em' };
 
-export default function PropertyColor({value, onUpdate, configs}) {
+export default function PropertyColor({value, onUpdate, configs, sourceElement}) {
   return (
-    <table className="PropertyColor" style={{ width: "100%", borderSpacing: "2px 0", marginBottom: "2px" }}>
+    <table className="PropertyColor" style={tableStyle}>
       <tbody>
         <tr>
           <td style={firstTdStyle}>
@@ -27,4 +26,5 @@ PropertyColor.propTypes = {
   value: PropTypes.any.isRequired,
   onUpdate: PropTypes.func.isRequired,
   configs: PropTypes.object.isRequired,
+  sourceElement: PropTypes.object
 };
