@@ -13,7 +13,7 @@ const firstTdStyle = { width: '6em' };
 const secondTdStyle = { padding: 0 };
 const unitContainerStyle = { width:'5em'};
 
-export default function PropertyLengthMeasure({value, onUpdate, configs}, {catalog}) {
+export default function PropertyLengthMeasure({value, onUpdate, configs, sourceElement}, {catalog}) {
 
   let _length = value.has('_length') ? value.get('_length') : value.get('length');
   let _unit = value.has('_unit') ? value.get('_unit') : UNIT_CENTIMETER;
@@ -62,7 +62,8 @@ export default function PropertyLengthMeasure({value, onUpdate, configs}, {catal
 PropertyLengthMeasure.propTypes = {
   value: PropTypes.instanceOf(Map).isRequired,
   onUpdate: PropTypes.func.isRequired,
-  configs: PropTypes.object.isRequired
+  configs: PropTypes.object.isRequired,
+  sourceElement: PropTypes.object
 };
 
 PropertyLengthMeasure.contextTypes = {
